@@ -6,7 +6,7 @@ from inspect import getmembers, ismethod
 from django.db.models import Model
 from django.db.models.query import QuerySet
 from django.db.models.sql import AND, OR
-from django.db.models.sql.query import ExtraWhere
+from django.db.models.sql.query import Query, ExtraWhere
 
 
 LONG_DISJUNCTION = 8
@@ -74,11 +74,13 @@ def dnf(qs):
     def _dnf(where):
         if isinstance(where, tuple):
             constraint, lookup, annotation, value = where
-            if constraint.alias != alias or isinstance(value, QuerySet):
+            if constraint.alias != alias or isinstance(value, (QuerySet, Query)):
                 return [[]]
             elif lookup == 'exact':
                 # attribute, value, negation
                 return [[(attname_of(model, constraint.col), value, True)]]
+            elif lookup == 'isnull':
+                return [[(attname_of(model, constraint.col), None, value)]]
             elif lookup == 'in' and len(value) < LONG_DISJUNCTION:
                 return [[(attname_of(model, constraint.col), v, True)] for v in value]
             else:
